Header menu logo FSharp.Control.TaskSeq

FSharp.Control Namespace

Type/Module Description

Async

AsyncExtensions

Debug

HighPriority

Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression.

Internal

LowPriority

Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression.

MediumPriority

Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression.

ResumableTSC<'T>

TaskSeqCode type alias of ResumableCode delegate type, specially recognized by the F# compiler

Task

TaskExtensions

TaskSeq

TaskSeq<'T>

Represents a task sequence and is the output of using the taskSeq{...} computation expression from this library. It is an alias for IAsyncEnumerable<_>.

TaskSeq<'Machine, 'T>

Main implementation of generic IAsyncEnumerable<'T> and related interfaces, which forms the meat of the logic behind taskSeq computation expresssions. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state.

TaskSeqBase<'T>

Abstract base class for TaskSeq<'Machine, 'T>. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state.

TaskSeqBuilder (Module)

TaskSeqBuilder (Type)

Main builder class for the taskSeq computation expression.

TaskSeqExtensions

TaskSeqStateMachine<'T>

Contains the state data for the taskSeq computation expression builder. For use in this library only. Required by the Run method.

TaskSeqStateMachineData<'T>

Contains the state data for the taskSeq computation expression builder. For use in this library only. Required by the Run method.

ValueTask

ValueTaskExtensions

Type something to start searching.