Header menu logo FSharp.Control.TaskSeq

HighPriority Module

Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression.

Type extensions

Type extension Description

this.Bind

Full Usage: this.Bind

Parameters:
Returns: ResumableTSC<'U>
Modifiers: inline
Type parameters: 'T, 'U

Extended Type: TaskSeqBuilder

task : Task<'T>
continuation : 'T -> ResumableTSC<'U>
Returns: ResumableTSC<'U>

this.Bind

Full Usage: this.Bind

Parameters:
Returns: ResumableTSC<'U>
Modifiers: inline
Type parameters: 'T, 'U

Extended Type: TaskSeqBuilder

computation : Async<'T>
continuation : 'T -> ResumableTSC<'U>
Returns: ResumableTSC<'U>

Type something to start searching.