Header menu logo FSharp.Control.TaskSeq

TaskSeq<'Machine, 'T> Type

Main implementation of generic IAsyncEnumerable<'T> and related interfaces, which forms the meat of the logic behind taskSeq computation expresssions. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state.

Record fields

Record Field Description

_initialMachine

Full Usage: _initialMachine

Field type: 'Machine
Modifiers: mutable
Field type: 'Machine

_machine

Full Usage: _machine

Field type: 'Machine
Modifiers: mutable

Keeps the active state machine.

Field type: 'Machine

Constructors

Constructor Description

TaskSeq()

Full Usage: TaskSeq()

Returns: TaskSeq<'Machine, 'T>
Returns: TaskSeq<'Machine, 'T>

Instance members

Instance member Description

this.InitMachineData

Full Usage: this.InitMachineData

Parameters:
ct : CancellationToken
machine : byref<'Machine>

Type something to start searching.