Header menu logo FSharp.Control.TaskSeq

TaskSeqStateMachineData<'T> Type

Contains the state data for the taskSeq computation expression builder. For use in this library only. Required by the Run method.

Record fields

Record Field Description

awaiter

Full Usage: awaiter

Field type: ICriticalNotifyCompletion
Modifiers: mutable

boxedSelf

Full Usage: boxedSelf

Field type: TaskSeqBase<'T>
Modifiers: mutable

A reference to 'self', because otherwise we can't use byref in the resumable code.

Field type: TaskSeqBase<'T>

builder

Full Usage: builder

Field type: AsyncIteratorMethodBuilder
Modifiers: mutable

Helper struct providing methods for awaiting 'next' in async iteration scenarios.

Field type: AsyncIteratorMethodBuilder

cancellationToken

Full Usage: cancellationToken

Field type: CancellationToken
Modifiers: mutable
Field type: CancellationToken

completed

Full Usage: completed

Field type: bool
Modifiers: mutable

Whether or not a full iteration through the IAsyncEnumerator has completed

Field type: bool

current

Full Usage: current

Field type: ValueOption<'T>
Modifiers: mutable

Used by the AsyncEnumerator interface to return the Current value when IAsyncEnumerator.Current is called

Field type: ValueOption<'T>

disposalStack

Full Usage: disposalStack

Field type: ResizeArray<(unit -> Task)>
Modifiers: mutable

Keeps track of the objects that need to be disposed off on IAsyncDispose.

Field type: ResizeArray<(unit -> Task)>

promiseOfValueOrEnd

Full Usage: promiseOfValueOrEnd

Field type: ManualResetValueTaskSourceCore<bool>
Modifiers: mutable

Constructors

Constructor Description

TaskSeqStateMachineData()

Full Usage: TaskSeqStateMachineData()

Returns: TaskSeqStateMachineData<'T>

Instance members

Instance member Description

this.PopDispose

Full Usage: this.PopDispose

this.PushDispose

Full Usage: this.PushDispose

Parameters:
    disposer : unit -> Task

disposer : unit -> Task

Type something to start searching.