FSharp.Control Namespace
| Type/Module | Description |
|
|
|
|
|
|
|
|
|
|
Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression. |
|
|
|
|
|
Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression. |
|
|
Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression. |
|
|
TaskSeqCode type alias of ResumableCode delegate type, specially recognized by the F# compiler |
|
|
|
|
|
|
|
|
|
|
|
Represents a task sequence and is the output of using the taskSeq{...} computation expression from this library. It is an alias for IAsyncEnumerable<_>. |
|
|
Main implementation of generic IAsyncEnumerable<'T> and related interfaces, which forms the meat of the logic behind taskSeq computation expresssions. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state. |
|
|
Abstract base class for TaskSeq<'Machine, 'T>. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state. |
|
|
|
|
|
Main builder class for the taskSeq computation expression. |
|
|
|
|
|
|
|
|
|
FSharp.Control.TaskSeq