HighPriority Module
Contains low priority extension methods for the main builder class for the taskSeq computation expression. The LowPriority, MediumPriority and HighPriority modules are not meant to be accessed directly from user code. They solely serve to disambiguate overload resolution inside the taskSeq computation expression.
Type extensions
| Type extension |
Description
|
Full Usage:
this.Bind
Parameters:
Task<'T>
continuation : 'T -> ResumableTSC<'U>
Returns: ResumableTSC<'U>
Modifiers: inline Type parameters: 'T, 'U |
Extended Type:
|
Full Usage:
this.Bind
Parameters:
Async<'T>
continuation : 'T -> ResumableTSC<'U>
Returns: ResumableTSC<'U>
Modifiers: inline Type parameters: 'T, 'U |
Extended Type:
|
FSharp.Control.TaskSeq