TaskSeq<'Machine, 'T> Type
Main implementation of generic IAsyncEnumerable<'T> and related interfaces, which forms the meat of the logic behind taskSeq computation expresssions. For use by this library only, should not be used directly in user code. Its operation depends highly on resumable state.
Record fields
| Record Field |
Description
|
Full Usage:
_initialMachine
Field type: 'Machine
Modifiers: mutable |
|
Full Usage:
_machine
Field type: 'Machine
Modifiers: mutable |
Keeps the active state machine.
|
Constructors
| Constructor |
Description
|
|
Instance members
| Instance member |
Description
|
|
|
FSharp.Control.TaskSeq