TaskSeq Module
Functions and values
| Function or value |
Description
|
||||
|
Returns the average of all elements of the task sequence. The elements must support the
|
||||
|
Returns the average of the results generated by applying the projection function to each element
of the task sequence. The result type must support the
|
||||
Full Usage:
averageByAsync projection source
Parameters:
'T -> Task<^U>
-
An async function to transform items from the input sequence into averageable values.
source : TaskSeq<'T>
-
The input task sequence.
Returns: Task<^U>
The average of the projected values.
Modifiers: inline Type parameters: 'T, ^U |
Returns the average of the results generated by applying the asynchronous projection function to
each element of the task sequence. The result type must support the
|
||||
Initialize an empty task sequence.
|
|||||
|
Returns the sum of all elements of the task sequence. The elements must support the
|
||||
|
Returns the sum of the results generated by applying the projection function to each element
of the task sequence. The result type must support the
|
||||
Full Usage:
sumByAsync projection source
Parameters:
'T -> Task<^U>
-
An async function to transform items from the input sequence into summable values.
source : TaskSeq<'T>
-
The input task sequence.
Returns: Task<^U>
The sum of the projected values.
Modifiers: inline Type parameters: 'T, ^U |
Returns the sum of the results generated by applying the asynchronous projection function to
each element of the task sequence. The result type must support the
|
FSharp.Control.TaskSeq