TaskSeqStateMachineData<'T> Type
Record fields
| Record Field |
Description
|
|
|
|
A reference to 'self', because otherwise we can't use byref in the resumable code.
|
|
Helper struct providing methods for awaiting 'next' in async iteration scenarios.
|
|
|
Full Usage:
completed
Field type: bool
Modifiers: mutable |
Whether or not a full iteration through the IAsyncEnumerator has completed
|
|
Used by the AsyncEnumerator interface to return the Current value when IAsyncEnumerator.Current is called
|
|
Keeps track of the objects that need to be disposed off on IAsyncDispose.
|
|
|
Constructors
| Constructor |
Description
|
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.PopDispose
|
|
|
|
FSharp.Control.TaskSeq